0.9.9 API documentation: quaternion_float_precision.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

quaternion_float_precision.hpp
Go to the documentation of this file.
1
11 #pragma once
12
13 // Dependency:
14 #include "../detail/type_quat.hpp"
15
16 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
17 # pragma message("GLM: GLM_EXT_quaternion_float_precision extension included")
18 #endif
19
20 namespace glm
21 {
24
26 typedef qua<float, lowp> lowp_quat;
27
29 typedef qua<float, mediump> mediump_quat;
30
32 typedef qua<float, highp> highp_quat;
33
35 } //namespace glm
36
glm::highp_quat
qua< float, highp > highp_quat
Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs...
Definition: quaternion_float_precision.hpp:32
glm::mediump_quat
qua< float, mediump > mediump_quat
Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs...
Definition: quaternion_float_precision.hpp:29
glm::lowp_quat
qua< float, lowp > lowp_quat
Quaternion of single-precision floating-point numbers using high precision arithmetic in term of ULPs...
Definition: quaternion_float_precision.hpp:26
glm
Definition: common.hpp:20